@@ -352,3 +352,23 @@ class TheBlockchainAPIResource:
         if 'error_message' in response:
             raise Exception(response['error_message'])
         return response
+
+    def get_airdrop(
+        self,
+        recipient_address: str
+    ) -> str:
+        """
+        Get an airdrop of 0.015 SOL on the devnet
+        :param recipient_address:
+        :return: Transaction signature
+        """
+        response = self._request(
+            payload={
+                "recipient_address": recipient_address
+            },
+            endpoint="solana/wallet/airdrop",
+            request_method=self.__RequestMethod.POST
+        )
+        if 'error_message' in response:
+            raise Exception(response['error_message'])
+        return response['transaction_signature']
